<?php


const DEBUG = false;
const INPUT = 'woo_ext_input.txt';


if (DEBUG) {

	ini_set('display_startup_errors', 1);
	ini_set('display_errors', 1);
	error_reporting(-1);

}


$dbInput = readLines(INPUT);

foreach ($dbInput as $access) {

	if (count(explode(':::', $access)) != 5) {
		continue;
	} 

	list($host, $user, $password, $dbName, $prefix) = explode(':::', $access);

	if ($dbName) {

		try {

			process($host, $user, $password, $dbName, $prefix);
				
		} catch (Exception $e) {

			if (DEBUG) {

				echo "{$host}, {$user}, {$password}, {$dbName} FAIL\n";

			}
				
		}
	}

	try {

		$pdo = getPdo($host, $user, $password, $dbName);

		$dbNames = getAllDBs($pdo);

	} catch (Exception $e) {

		if (DEBUG) {

			echo "{$host}, {$user}, {$password}, {$dbName} FAIL\n";
		}

		continue;

	}



	foreach ($dbNames as $dbName) {

		try {

			$pdo = getPdo($host, $user, $password, $dbName);

			$prefix = getPrefix($pdo);

			process($host, $user, $password, $dbName, $prefix);
				
		} catch (Exception $e) {

			if (DEBUG) {

				echo "{$host}, {$user}, {$password}, {$dbName} FAIL\n";
			}

		}
		
	}


}






function process($host, $user, $password, $dbName, $prefix)
{

	
	$pdo = getPdo($host, $user, $password, $dbName);

	$domain = getDomain($pdo, $prefix);

	$ordersCount = getOrdersCount($pdo, $prefix);

	$report = "{$domain} - {$dbName} - {$ordersCount}";

	echo $report . PHP_EOL;

}


function getAllDBs($pdo)
{

	$stmt = $pdo->query('SHOW DATABASES');

	return $stmt->fetchAll(PDO::FETCH_COLUMN);
}

function getPrefix($pdo)
{
	$stmt = $pdo->query('SHOW TABLES');

	$tables = $stmt->fetchAll(PDO::FETCH_COLUMN);

	$prefix1 = null;
	
	$prefix2 = null;

	foreach ($tables as $table) {

		if (strpos($table, '_posts') !== false) {
			$prefix1 = str_replace('_posts', '', $table);
		}

		if (strpos($table, '_postmeta') !== false) {
			$prefix2 = str_replace('_postmeta', '', $table);
		}
	}

	if (!is_null($prefix1) && ($prefix1 == $prefix2)) {

		return $prefix1 . '_';

	} else {

		return 'wp_';

	}

}


function getDomain($pdo, $prefix)
{


	$stmt = $pdo->query("SELECT option_value FROM {$prefix}options WHERE option_name = 'home'");

	$result = $stmt->fetch(PDO::FETCH_COLUMN);

	return preg_replace('#http(s)?://#', '', $result);

}


function getOrdersCount($pdo, $prefix)
{

    $stmt = $pdo->query("SELECT pm.meta_value AS user_id, pm.post_id AS order_id
        FROM {$prefix}postmeta AS pm
        LEFT JOIN {$prefix}posts AS p
        ON pm.post_id = p.ID
        WHERE p.post_type = 'shop_order'
        AND p.post_status = 'wc-completed'
        AND pm.meta_key = '_customer_user'
        AND MONTH(post_date) = MONTH(CURRENT_DATE())
        ORDER BY pm.meta_value ASC, pm.post_id DESC");

    return count($stmt->fetchAll(PDO::FETCH_ASSOC));
}


function getData($pdo)
{

	$stmt = $pdo->query('SELECT table_name FROM information_schema.tables;');

	$result = $stmt->fetchALL(PDO::FETCH_COLUMN);

}


function getPdo($host, $user, $password, $dbName)
{

	$result = new PDO("mysql:host={$host};dbname={$dbName}", $user, $password);
	$result->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

	return $result;

}


function readLines($fileName) 
{

	if (!file_exists($fileName)) {
		throw new Exception("{$fileName} not found", 1);
		
	}

	return file($fileName, FILE_IGNORE_NEW_LINES | FILE_SKIP_EMPTY_LINES);
}



